API
---

.. automodule:: calcifer
   :members:

.. automodule:: calcifer.operators

   .. autofunction:: attempt
   .. autofunction:: append_value
   .. autofunction:: check
   .. autofunction:: children
   .. autofunction:: collect
   .. autofunction:: define_as
   .. autofunction:: each
   .. autofunction:: fail
   .. autofunction:: forbid_value
   .. autofunction:: get_node
   .. autofunction:: get_value
   .. autofunction:: match
   .. autofunction:: permit_values
   .. autofunction:: policies
   .. autofunction:: pop_context
   .. autofunction:: push_context
   .. autofunction:: regarding
   .. autofunction:: require_value
   .. autofunction:: scope
   .. autofunction:: select
   .. autofunction:: set_value
   .. autofunction:: trace
   .. autofunction:: unit
   .. autofunction:: unit_value
   .. autofunction:: unless_errors
   .. autofunction:: wrap_context
